/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994
 * Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the Tektronix XP119 with 
 * Sun type 5 PC-style keyboard,
 * By Michael Lemke <michael@io.as.utexas.edu>.
 */

static const KeyCode tek119_codes [] = {

  /* Row 0 */
  17, 16,
  15, 23, 31, 39,
  47, 55, 63, 71,
  79, 87, 94, 102,
  95, 103, 106,
  88, 89, 91, 101,

  /* Row 1 */
  18, 19,
  22, 30, 38, 46, 45, 54, 62, 69, 70, 78, 77, 86, 93, 110,
  111, 118, 119,
  126, 127, 134, 140,

  /* Row 2 */
  20, 24,
  21, 29, 37, 44, 53, 52, 61, 68, 75, 76, 85, 92, 99, 100,
  108, 109, 117,
  116, 125, 133, 132,


  /* Row 3 */
  27, 32,
  28, 36, 35, 43, 51, 60, 59, 67, 74, 83, 84, 90, 98,
  115, 123, 124,


  /* Row 4 */
  40, 48,
  26, 34, 42, 41, 50, 58, 57, 66, 73, 81, 82, 97,
  107,
  113, 122, 130, 129,


  /* Row 5 */
  56, 64,
  25, 33, 72, 49, 80, 65, 96,
  105, 104, 114,
  120, 121
};
